@@ -9,6 +9,9 @@ import re
 import datetime
 import pathlib
 import hashlib
+import subprocess
+import requests
+import json
 
 
 def fix_block_encoding_errors(block):
@@ -150,19 +153,32 @@ def replace_string_in_file(path, regex, replaced, flags=0):
         return False
 
 
-def get_directory_size(path, lvl=0, max_lvl=100, verbose=False):
+start_time = 0
+
+
+def get_directory_size(path, lvl=0, max_lvl=100, time_limit=5, verbose=False):
+    global start_time
     total = 0
+
+    if lvl == 0:
+        start_time = time.perf_counter()
+
     lvl += 1
     if not os.path.isdir(path):
         return 0
     with os.scandir(path) as it:
         for entry in it:
+            exec_time = time.perf_counter() - start_time
+            if exec_time > time_limit:
+                print('time limit reached (%ss)' % time_limit)
+                return total
             try:
                 if entry.is_file() or entry.is_symlink():
                     size = entry.stat(follow_symlinks=False).st_size
 
                     if entry.stat().st_nlink > 1 and not entry.is_symlink():
-                        print('nlink: %s %s delim: %s/%s' % (entry.stat().st_nlink, entry.name, size, entry.stat().st_nlink))
+                        if verbose:
+                            print('nlink: %s %s delim: %s/%s' % (entry.stat().st_nlink, entry.name, size, entry.stat().st_nlink))
                         size = size / entry.stat().st_nlink
                     if verbose:
                         print('%s : %s' % (entry.name, size))
@@ -258,6 +274,49 @@ def chown(path, username, group=None, recursive=True):
         os.system('chown {0}{1}:{2} "{3}"'.format(r_str, username, group, path))
 
 
+default_interfaces = ['enp', 'eth']
+
+
+def get_interface(interfaces=None):
+    if not interfaces:
+        interfaces = default_interfaces
+    for inet in os.listdir('/sys/class/net/'):
+        for interface in interfaces:
+            if interface in inet:
+                return inet
+    return False
+
+
+def get_ip_addresses(interface=None):
+    if os.name == 'posix':
+        return _get_ip_addresses_linux(interface)
+    elif os.name == 'nt':
+        return _get_ip_addresses_windows()
+    else:
+        raise RuntimeError("Unsupported OS")
+
+
+def get_external_ip():
+    group = json.loads(requests.get('http://jsonip.com/').content.decode())
+    return group['ip']
+
+
+def _get_ip_addresses_linux(interface=None):
+    if not interface:
+        interface = get_interface()
+    output = subprocess.getoutput('ip address show %s' % interface)
+    ips_list = re.findall(r'inet (\d+\.\d+\.\d+\.\d+)', output)
+
+    return ips_list
+
+
+def _get_ip_addresses_windows():
+    output = subprocess.getoutput('ipconfig')
+    ips_list = re.findall(r'IPv4 Address.*: (\d+\.\d+\.\d+\.\d+)', output)
+
+    return ips_list
+
+
 class Logger:
     def __init__(self, to_console=True, file=None):
         self._to_console = to_console
